diff tools/lib64gfx.h @ 2056:c27ed6465022

Add pixel aspect ratio information for C64 formats. Not used yet.
author Matti Hamalainen <ccr@tnsp.org>
date Tue, 04 Dec 2018 15:31:13 +0200
parents e7f2ddaf94a6
children 4276b8c0fef0
line wrap: on
line diff
--- a/tools/lib64gfx.h	Tue Dec 04 10:33:06 2018 +0200
+++ b/tools/lib64gfx.h	Tue Dec 04 15:31:13 2018 +0200
@@ -202,7 +202,8 @@
 {
     int  type,               // Type flags, see D64_FMT_*
          width, height,      // Width and height in pixels
-         chWidth, chHeight;  // Width and height in charblocks
+         chWidth, chHeight,  // Width and height in charblocks
+         aspectX, aspectY;   // Pixel aspectX/Y
 
     int  (*convertFrom)(DMImage *, const DMC64Image *, const DMC64ImageFormat *fmt, const DMC64ImageConvSpec *spec);
     int  (*convertTo)(DMC64Image *, const DMImage *, const DMC64ImageFormat *fmt, const DMC64ImageConvSpec *spec);